@@ -11,6 +11,8 @@ def check_comparability(py_object: object, deserialized_py_object: object) -> bo
 def get_type(py_object: object) -> str:
     if py_object is None:
         return 'types.NoneType'
+    if callable(py_object):
+        return 'typing.Callable'
     module = type(py_object).__module__
     return '{module}.{name}'.format(
         module=module,
@@ -37,6 +39,8 @@ def has_reduce(py_object: object) -> bool:
         return False
     except pickle.PicklingError:
         return False
+    except Exception:
+        return False
 
 
 def get_repr(py_object: object) -> str:
@@ -55,6 +59,22 @@ def get_repr(py_object: object) -> str:
     return repr(py_object)
 
 
+def has_repr(py_object: object) -> bool:
+    try:
+        pickle.dumps(py_object)
+    except pickle.PicklingError:
+        return False
+
+    try:
+        r = repr(py_object)
+        if not isinstance(py_object, str) and r.startswith('<') and r.endswith('>'):
+            return False
+    except Exception:
+        return False
+
+    return True
+
+
 def getattr_by_path(py_object: object, path: str) -> object:
     current_object = py_object
     for layer in path.split("."):
